pyPENELOPEtools
===============

**pyPENELOPEtools** is an open-source software to facilitate the use of the 
Monte Carlo code PENELOPE and its main programs such as PENEPMA. 
It is a programming interface to setup, run and analyze Monte Carlo simulations.
Most of the code was adapted from `pyPENELOPE <http://pypenelope.sourceforge.net>`_, 
but with the goal to facilitate the integration with 
`pyMonteCarlo <https://github.com/pymontecarlo/pymontecarlo>`_.

.. warning::

   **pyPENELOPEtools** does not contain executables of PENELOPE or any of its 
   main programs.
   It also does not provide any code to execute these programs.
   It provides tools to create the input file(s) (e.g. ``.in``) for the main
   programs and to parse the output file(s) from the simulations (e.g. ``.dat``).

Contents:

.. toctree::
   :maxdepth: 2

   installation
   tutorial
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

